



hydrotrend -h
IF %ERRORLEVEL% NEQ 0 exit /B 1
hydrotrend -v
IF %ERRORLEVEL% NEQ 0 exit /B 1
curl https://raw.githubusercontent.com/csdms-contrib/hydrotrend/master/data/input/HYDRO.IN > ./HYDRO.IN
IF %ERRORLEVEL% NEQ 0 exit /B 1
curl https://raw.githubusercontent.com/csdms-contrib/hydrotrend/master/data/input/HYDRO0.HYPS > ./HYDRO0.HYPS
IF %ERRORLEVEL% NEQ 0 exit /B 1
hydrotrend
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
